pub enum RequestedObject<T: Send + 'static> {
Pending {
rx: Receiver<T>,
previous: Option<T>,
},
Completed(T),
}Expand description
A handle to an object that is requested asynchronously.
Note: this object cannot be Clone because it uses a one-shot channel to track completion of
the async operation.
Variants
Implementations
Sourceimpl<T: Send + 'static> RequestedObject<T>
impl<T: Send + 'static> RequestedObject<T>
Sourcepub fn new<F>(
runtime: &AsyncRuntimeHandle,
func: F,
previous: Option<T>,
) -> Self
pub fn new<F>( runtime: &AsyncRuntimeHandle, func: F, previous: Option<T>, ) -> Self
Create a new Self with the given future.
Optionally retains a previous value while the future is pending.
Sourcepub fn new_with_repaint<F>(
runtime: &AsyncRuntimeHandle,
egui_ctx: Context,
func: F,
) -> Self
pub fn new_with_repaint<F>( runtime: &AsyncRuntimeHandle, egui_ctx: Context, func: F, ) -> Self
Create a new Self with the given future and automatically request a repaint of the UI
when the future completes.
Sourcepub fn refresh_with_previous_and_repaint<F>(
self,
runtime: &AsyncRuntimeHandle,
egui_ctx: Context,
func: F,
) -> Self
pub fn refresh_with_previous_and_repaint<F>( self, runtime: &AsyncRuntimeHandle, egui_ctx: Context, func: F, ) -> Self
Refresh the requested object, retaining the latest available object while the new request is pending.
Sourcepub fn on_frame_start(&mut self)
pub fn on_frame_start(&mut self)
Check if the future has completed and, if so, update our state to Self::Completed.
Sourcepub fn try_as_ref(&self) -> Option<&T>
pub fn try_as_ref(&self) -> Option<&T>
Get a reference to the latest available object.
Sourcepub fn take_latest(self) -> Option<T>
pub fn take_latest(self) -> Option<T>
Take the latest available object, if any.